@@ -98,7 +98,7 @@ public:
     ~SidebarMode() override;
     QWidget *mainWidget();
     void initEvent();
-    void giveFocus();
+    Q_INVOKABLE void giveFocus();
     ModuleView *moduleView() const;
     void reloadStartupModule();
 
@@ -120,9 +120,12 @@ public:
     bool defaultsIndicatorsVisible() const;
     void toggleDefaultsIndicatorsVisibility();
 
+    void toggleShowIrrelevantModules();
+
     Q_INVOKABLE QAction *action(const QString &name) const;
     // QML doesn't understand QIcon, otherwise we could get it from the QAction itself
     Q_INVOKABLE QString actionIconName(const QString &name) const;
+    Q_INVOKABLE QString actionIconName(const QAction *action) const;
     Q_INVOKABLE void showActionMenu(const QPoint &position);
 
     Q_INVOKABLE void loadModule(const QModelIndex &activeModule, const QStringList &args = QStringList());
